Building the lesson
===================

It is built the normal Sphinx way::

  make html
  # or
  make dirhtml
  # full build
  make clean html

However, there are different ways to set up a Sphinx project.  Our
sample project puts the results in ``_build/``.
